bayespy.inference.vmp.nodes.binomial.BinomialMoments.compute_dims_from_values
=============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.binomial

.. automethod:: BinomialMoments.compute_dims_from_values